@@ -8,12 +8,12 @@ from collections.abc import Awaitable
 from functools import lru_cache
 from typing import Optional, Union
 
-from f1z1_common import is_validators, TimestampUtil, TimestampUnit
+from f1z1_common import is_validators, TimeUnit, UnitOfTime
 
 from .base import IAwaitSpeed
 
 SpeedTypes = Union[int, float]
-SpeedUnit = Optional[TimestampUnit]
+SpeedUnit = Optional[UnitOfTime]
 
 
 class Speed(Awaitable, IAwaitSpeed):
@@ -23,9 +23,9 @@ class Speed(Awaitable, IAwaitSpeed):
 
     def __init__(self,
                  speed: SpeedTypes,
-                 unit: SpeedUnit = TimestampUnit.MILLISECOND):
+                 unit: SpeedUnit = UnitOfTime.MILLISECOND):
         self._speed = speed
-        self._unit = unit
+        self._unit = TimeUnit(unit)
 
     @property
     def speed(self):
@@ -41,9 +41,9 @@ class Speed(Awaitable, IAwaitSpeed):
         return self._unit
 
     @unit.setter
-    def unit(self, unit: TimestampUnit) -> None:
+    def unit(self, unit: UnitOfTime) -> None:
         self._check_unit(unit)
-        self._unit = unit
+        self._unit = TimeUnit(unit)
 
     def __await__(self):
         return self._await_speed(self.computed_speed_use_lru()).__await__()
@@ -51,12 +51,9 @@ class Speed(Awaitable, IAwaitSpeed):
     async def _await_speed(self, speed: SpeedTypes):
         return await sleep(speed)
 
-    def computed_speed_use_lru(self):
-        return self._get_speed_use_lru()
-
     @lru_cache()
-    def _get_speed_use_lru(self):
-        return TimestampUtil.to_timestamp(self.speed, self.unit)
+    def computed_speed_use_lru(self):
+        return self.speed / self.unit.get_time_unit()
 
     def _check_speed(self, speed):
         if not is_validators.is_number(speed):
